import React, { useCallback, useMemo } from 'react';
import { Connection, getConnectedEdges, Handle, HandleProps, Position, useNodeId, useStore } from 'reactflow';
import { Handles, QueryGraphEdgeHandle, toHandleData, toHandleId } from '../model';

const selector = (s: any) => ({
  nodeInternals: s.nodeInternals,
  edges: s.edges,
});

export const FilterHandle = (
  props: {
    handle: QueryGraphEdgeHandle;
  } & Omit<HandleProps, 'id'> &
    Omit<React.HTMLAttributes<HTMLDivElement>, 'id'>
) => {
  const { nodeInternals, edges } = useStore(selector);
  const nodeId = useNodeId();

  const sourceWithLogic = useMemo(() => {
    return (
      props.handle.handleType === Handles.LogicLeft ||
      props.handle.handleType === Handles.LogicRight ||
      props.handle.handleType === Handles.EntityAttribute ||
      props.handle.handleType === Handles.RelationAttribute
    );
  }, [props.handle]);

  const id = useMemo(() => {
    return toHandleId(props.handle);
  }, [props.handle]);

  const isValidConnection = useCallback(
    (connection: Connection) => {
      if (!connection.targetHandle) return false;
      let target = toHandleData(connection.targetHandle);

      // do not allow self connection between two relation nodes
      if (
        props.handle.nodeId === target.nodeId &&
        (props.handle.handleType === Handles.RelationLeft || props.handle.handleType === Handles.RelationRight)
      )
        return false;

      const targetHandleOfTypeLogic =
        target.handleType === Handles.LogicLeft ||
        target.handleType === Handles.LogicRight ||
        target.handleType === Handles.EntityAttribute ||
        target.handleType === Handles.RelationAttribute;

      // only allow if both are logic or non-logic
      if (sourceWithLogic === targetHandleOfTypeLogic) return true;
      else return false;
    },
    [nodeInternals, edges, nodeId, props.handle]
  );

  return <Handle id={id} {...props} isValidConnection={isValidConnection}></Handle>;
};
