import React, { useRef } from 'react';
import ArrowBackIosIcon from '@mui/icons-material/ArrowBackIos';
import ArrowForwardIosIcon from '@mui/icons-material/ArrowForwardIos';

interface PaginationProps {
  currentPage: number;
  totalPages: number;
  onPageChange: (page: number) => void;
  itemsPerPageInput: number;
  numItemsArrayReal: number;
  totalItems: number;
}

const Pagination: React.FC<PaginationProps> = ({
  currentPage,
  totalPages,
  onPageChange,
  itemsPerPageInput,
  numItemsArrayReal,
  totalItems,
}) => {
  const pageNumbers = Array.from({ length: totalPages }, (_, index) => index + 1);

  const firstItem = (currentPage - 1) * itemsPerPageInput + 1;
  const lastItem = Math.min(currentPage * itemsPerPageInput, totalPages);

  const goToPreviousPage = () => {
    if (currentPage > 1) {
      onPageChange(currentPage - 1);
    }
  };

  const goToNextPage = () => {
    if (currentPage < totalPages) {
      onPageChange(currentPage + 1);
    }
  };

  return (
    <div className="table-pagination h-full flex flex-col items-center">
      <span className="inline-block m-2 max-w-32 min-w-32">{`${firstItem}-${numItemsArrayReal} of ${totalItems}`}</span>
      <div className="join">
        <button className="m-1 btn btn-outline" onClick={goToPreviousPage} disabled={currentPage === 1}>
          <ArrowBackIosIcon /> Previous
        </button>
        <button className="m-1 btn btn-outline" onClick={goToNextPage} disabled={currentPage === totalPages}>
          <ArrowForwardIosIcon /> Next
        </button>
      </div>
    </div>
  );
};

export default Pagination;
